logger

package
v0.0.0-...-207d3b7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 15, 2024 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Logger

type Logger = *zap.SugaredLogger

Added an alias to the logger from the zap package so it can be easily replaced in the future if necessary.

func NewLogger

func NewLogger() (Logger, error)

Jump to